// -*- coding: utf-8 -*-
// Custom Universe
// Extended Solar System
// JackDole 2016.05.18 08:07:21
// For SE 0.974 RC2

// Put this script in the 'addons\catalogs\planets' folder
//------------------------------------------------------------------------------

Remove "Sol" { ParentBody "Sun" }
Remove "Jupiter" { ParentBody "Sol" }
Remove "Saturn" { ParentBody "Sol" }
Remove "Uranus" { ParentBody "Sol" }
Remove "Neptune" { ParentBody "Sol" }
Remove "Pluto-Charon" { ParentBody "Sol" }
Remove "Haumea" { ParentBody "Sol" }
Remove "Makemake" { ParentBody "Sol" }
Remove "Eris" { ParentBody "Sol" }

Barycenter "Sol-Jupiter"
{
    ParentBody  "Sol-Barycenter"
    
    MassSol     1.0027
    
    Orbit
    {
        Epoch           2455563
        SemiMajorAxis   9296.438331
        Period          26000000
        Eccentricity    0.8
        Inclination     81
        AscendingNode   0
        ArgOfPericenter 0
        MeanAnomaly     333
        RefPlane       "Ecliptic"
    }
}

Star "Sol/The Sun"
{
    ParentBody  "Sol-Jupiter"
    Class       "G2 V"
    MassSol     1
    RadSol      1
    Lum         1
    AbsMagn     4.83
    Teff        5860
    Age         4.57
    FeH         0.0122
    
    Orbit
    {
        RefPlane        "Ecliptic"
        SemiMajorAxis   0.004962
        Period          11.8622
        Eccentricity    0.0484
        Inclination     1.3053
        AscendingNode   100.556
        ArgOfPericenter 94.1979
        MeanAnomaly     19.6501
    }
}

Planet "Jupiter"
{
    ParentBody     "Sol-Jupiter"
    Class          "GasGiant"

    Mass            317.832
    Radius          71492
    Oblateness      0.06487

    RotationPeriod  9.92425
    RotationOffset  305.4
    Obliquity       2.222461
    EqAscendNode   -22.203

    Albedo          0.343 
    AlbedoBond      0.343 
    AlbedoGeom      0.52
    Brightness      2.0

    Surface
    {
        // Surface map author: John van Vliet
        DiffMap        "Jupiter/Surface-JVV"
        DiffTileSize    256
        DiffTileBorder  0
        DayAmbient      0
    }

    NoClouds true

    Atmosphere
    {
        Height   300
        Model   "Jupiter"
        Bright   2.0
        Opacity  0.0
        SkyLight 0.0
        
        Composition
        {
            H2   89.8
            He   10.2
            CH4  0.3
            NH3  0.026
            C2H6 0.0006
        }
    }

    Aurora
    {
        Height       1000
        TopColor    (1.5 0.0 0.8)
        BottomColor (1.0 0.1 0.0)

        NorthLat     90
        NorthLon     0 
        NorthRadius  15000
        NorthWidth   5000
        NorthRings   3
        NorthBright  1.0

        SouthLat    -90
        SouthLon     0 
        SouthRadius  16000
        SouthWidth   5000
        SouthRings   3
        SouthBright  1.0
    }

    Rings
    {
        Texture         "Jupiter-rings.*"
        InnerRadius     102200
        OuterRadius     227000
        FrontBright     0.03
        BackBright      1.0
        Density         0.03
        Brightness      2.0
    }

    Orbit
    {
        RefPlane       "Ecliptic"
        Period          11.8622
        SemiMajorAxis   5.2034
        Eccentricity    0.0484
        Inclination     1.3053
        AscendingNode   100.556
        ArgOfPericenter -85.8021
        MeanAnomaly     19.6501
    }
}

Planet "Saturn"
{
    ParentBody     "Sol-Jupiter"
    Class          "GasGiant"

    Mass            95.162
    Radius          60268
    Oblateness      0.09796

    RotationPeriod  10.65622
    RotationOffset  358.922
    Obliquity       28.049
    EqAscendNode    169.53

    Color         ( 1.000 1.000 0.850 )
    Albedo          0.342
    AlbedoBond      0.342
    AlbedoGeom      0.47
    Brightness      1.8

    Surface
    {
        // Surface map author: Bjorn Jonsson
        DiffMap        "Saturn/Surface-BJ"
        DiffTileSize    256
        DiffTileBorder  0
        DayAmbient      0
    }

    NoClouds     true

    Atmosphere
    {
        Height   250
        Model   "Earth"
        Bright   5.0
        Opacity  0.2
        SkyLight 0.002
        
        Composition
        {
            H2   96.3
            He   3.25
            CH4  0.45
            NH3  0.0125
            C2H6 0.0007
        }
    }

    Aurora
    {
        Height       1000 
        TopColor    (1.5 0.0 0.8)
        BottomColor (1.0 0.1 0.0)

        NorthLat     90
        NorthLon     0 
        NorthRadius  15000
        NorthWidth   5000
        NorthRings   3
        NorthBright  1.0

        SouthLat    -90
        SouthLon     0 
        SouthRadius  16000
        SouthWidth   5000
        SouthRings   3
        SouthBright  1.0
    }

    Rings
    {
        // Rings texture author: Vladimir Romanyuk "SpaceEngineer"
        Texture        "Saturn-rings.*"
        InnerRadius     60284
        OuterRadius     356993
        FrontBright     1.0
        BackBright      5.0
        Brightness      1.5
    }

    Orbit
    {
        RefPlane       "Ecliptic"
        Period          29.4577
        SemiMajorAxis   9.5371
        Eccentricity    0.0542
        Inclination     2.4845
        AscendingNode   113.715
        LongOfPericen   92.432
        MeanLongitude   49.944
    }
}

Planet "Uranus"
{
    ParentBody     "Sol-Jupiter"
    Class          "IceGiant"

    Mass            14.536
    Radius          25559
    Oblateness      0.02293

    RotationPeriod  17.24
    RotationOffset  331.18
    Obliquity       97.81
    EqAscendNode    167.76

    Color         ( 0.750 0.850 1.000 )
    Albedo          0.30
    AlbedoBond      0.30
    AlbedoGeom      0.51
    Brightness      1.2

    Surface
    {
        DiffMap        "Uranus.*"
    }

    NoClouds    true

    Atmosphere
    {
        Height   300
        Model   "Earth"
        Bright   2.0
        Opacity  0.2
        SkyLight 0.002
        
        Composition
        {
            H2  82.5
            He  15.2
            CH4 2.3
        }
    }

    Aurora
    {
        Height       600 
        TopColor    (1.5 0.0 0.8)
        BottomColor (1.0 0.1 0.0)

        NorthLat     90
        NorthLon     0 
        NorthRadius  5000
        NorthWidth   1500
        NorthRings   3
        NorthBright  0.3

        SouthLat    -90
        SouthLon     0 
        SouthRadius  5000
        SouthWidth   1500
        SouthRings   3
        SouthBright  0.3
    }

    Rings
    {
        Texture        "Uranus-rings.*"
        InnerRadius     39501.5
        OuterRadius     53514.4
    }

    Orbit
    {
        RefPlane       "Ecliptic"
        Period          84.0139
        SemiMajorAxis   19.1913
        Eccentricity    0.0472
        Inclination     0.7699
        AscendingNode   74.23
        LongOfPericen   170.964
        MeanLongitude   313.232
    }
}

Planet "Neptune"
{
    ParentBody     "Sol-Jupiter"
    Class          "IceGiant"

    Mass            17.147
    Radius          24766
    Oblateness      0.01708

    RotationPeriod  16.11
    RotationOffset  228.65
    Obliquity       28.03
    EqAscendNode    49.235

    Color         ( 0.750 0.750 1.000 )
    Albedo          0.29 
    AlbedoBond      0.29 
    AlbedoGeom      0.41
    Brightness      1.07

    Surface
    {
        DiffMap        "Neptune.*"
    }

    NoClouds    true

    Atmosphere
    {
        Height   300
        Model   "Neptune"
        Bright   5.0
        Opacity  0.2
        SkyLight 0.2
        
        Composition
        {
            H2   80
            He   19
            CH4  1.5
            C2H6 0.00015
        }
    }

    Aurora
    {
        Height       600 
        TopColor    (1.5 0.0 0.8)
        BottomColor (1.0 0.1 0.0)

        NorthLat     90
        NorthLon     0 
        NorthRadius  5000
        NorthWidth   1500
        NorthRings   3
        NorthBright  0.3

        SouthLat    -90
        SouthLon     0 
        SouthRadius  5000
        SouthWidth   1500
        SouthRings   3
        SouthBright  0.3
    }

    Rings
    {
        Texture        "Neptune-rings.*"
        InnerRadius     50700.75
        OuterRadius     65396.25
    }

    Orbit
    {
        RefPlane       "Ecliptic"
        Period          164.793
        SemiMajorAxis   30.069
        Eccentricity    0.0086
        Inclination     1.7692
        AscendingNode   131.722
        LongOfPericen   44.971
        MeanLongitude   304.88
    }
}

Barycenter "Pluto-Charon"
{
    ParentBody     "Sol-Jupiter"
    Orbit
    {
        RefPlane       "Ecliptic"
        Period          248.54
        SemiMajorAxis   39.48168677
        Eccentricity    0.24880766
        Inclination     17.14175
        AscendingNode   110.30347
        LongOfPericen   224.06776
        MeanLongitude   238.92881
    }
}

DwarfPlanet "Haumea/(136108) Haumea/2003 EL61"
{
    ParentBody     "Sol-Jupiter"
    AsterType      "Cubewano"

    Radius          869.5 // mean equatorial radius // 980 // maximum semi-axis
    Oblateness      0.427
    Mass            0.00066

    RotationPeriod  3.9155
    Obliquity       126   // used Hi'iaka's orbit Inclination
    EqAscendNode    26    // used Hi'iaka's orbit AscendingNode

    AbsMagn         0.1
    SlopeParam      0.15
    Albedo          0.7
    Brightness      1.5 // 3.0

    Orbit
    {
        RefPlane       "Ecliptic"
        Epoch           2456401
        MeanMotion      0.00348839
        SemiMajorAxis   43.0579
        Eccentricity    0.195253
        Inclination     28.1941
        AscendingNode   121.819
        ArgOfPericenter 240.678
        MeanAnomaly     206.48
    }
}

DwarfPlanet "Makemake/(136472) Makemake/2005 FY9"
{
    ParentBody     "Sol-Jupiter"
    AsterType      "Cubewano"

    Radius          750
    Mass            0.0005

    AbsMagn        -0.4
    SlopeParam      0.15
    Albedo          0.78
    Brightness      1.5 // 2.5

    Orbit
    {
        RefPlane       "Ecliptic"
        Epoch           2456401
        MeanMotion      0.00320549
        SemiMajorAxis   45.5554
        Eccentricity    0.159941
        Inclination     29.0131
        AscendingNode   79.2872
        ArgOfPericenter 297.077
        MeanAnomaly     154.559
    }
}

DwarfPlanet "Eris/(136199) Eris"
{
    ParentBody     "Sol-Jupiter"

    Radius          1163
    Mass            0.0028

    RotationPeriod  25.9
    EqAscendNode    142  // used Dysnomia's orbit AscendingNode
    Obliquity       139  // used Dysnomia's orbit Inclination

    AbsMagn        -1.2
    SlopeParam      0.15
    Albedo          0.96
    Brightness      1.5 // 5.9

    Surface
    {
        colorSea       (1.000 1.000 1.000 0.500)
        colorShelf     (0.950 0.950 0.950 0.500)
        colorBeach     (0.750 0.750 0.750 1.000)
        colorDesert    (0.850 0.850 0.850 1.000)
        colorLowland   (0.870 0.870 0.870 1.000)
        colorUpland    (0.930 0.930 0.930 1.000)
        colorRock      (1.000 1.000 1.000 1.000)
        colorSnow      (1.000 1.000 1.000 1.000)
        colorLowPlants (0.870 0.870 0.870 1.000)
        colorUpPlants  (0.930 0.930 0.930 1.000)
        DayAmbient      0.2
        Hapke           0.8
    }

    Orbit
    {
        RefPlane       "Ecliptic"
        Epoch           2456401
        MeanMotion      0.00175931
        SemiMajorAxis   67.9581
        Eccentricity    0.437079
        Inclination     43.8851
        AscendingNode   36.031
        ArgOfPericenter 150.804
        MeanAnomaly     203.207
    }
}

//------------------------------------------------------------------------------
